@@ -1,4 +1,4 @@
-# $Id: /mirror/perl/XML-RSS-LibXML/trunk/lib/XML/RSS/LibXML.pm 7079 2007-05-07T15:12:17.278193Z daisuke  $
+# $Id: /mirror/coderepos/lang/perl/XML-RSS-LibXML/trunk/lib/XML/RSS/LibXML.pm 92874 2008-11-26T08:46:35.232842Z daisuke  $
 #
 # Copyright (c) 2005-2007 Daisuke Maki <daisuke@endeworks.jp>
 # All rights reserved.
@@ -13,7 +13,7 @@ use XML::LibXML;
 use XML::LibXML::XPathContext;
 use XML::RSS::LibXML::Namespaces qw(NS_RSS10);
 
-our $VERSION = '0.3001';
+our $VERSION = '0.3003';
 
 __PACKAGE__->mk_accessors($_) for qw(impl encoding strict namespaces modules output stylesheets _internal num_items);
 
@@ -33,6 +33,10 @@ sub new
         _internal  => {},
         stylesheets => $args{stylesheet} ? (ref ($args{stylesheet}) eq 'ARRAY' ? $args{stylesheet} : [ $args{stylesheet} ]) : [],
         num_items   => 0,
+        libxml_opts => $args{libxml_opts} || {
+            recover => 1,
+            load_ext_dtd => 0
+        }
     }, $class;
 
     $self->impl->reset($self);
@@ -129,7 +133,11 @@ sub create_libxml
 {
     my $self = shift;
     my $p    = XML::LibXML->new;
-    $p->recover(1);
+    my $opts = $self->{libxml_opts} || {};
+    while (my($key, $value) = each %$opts) {
+        $p->$key($value);
+    }
+
     return $p;
 }
 
@@ -169,7 +177,7 @@ sub get_namespaces
     my $self = shift;
     my $node = shift;
     my %h = map {
-        (($_->getName() || '#default') => $_->getData)
+        (($_->getLocalName() || '#default') => $_->getData)
     } $node->getNamespaces();
 
 #    while (my($p, $uri) = each %h) {
